AuthmeFeature enum
- Inheritance
- Available extensions
Values
- TWIDFraud → const AuthmeFeature
-
const AuthmeFeature('idCardFraud') - TWID → const AuthmeFeature
-
const AuthmeFeature('idCard') - TWDriverLicense → const AuthmeFeature
-
const AuthmeFeature('driverLicense') - TWHealth → const AuthmeFeature
-
const AuthmeFeature('healthCard') - TWNResident → const AuthmeFeature
-
const AuthmeFeature('residentCard') - Passport → const AuthmeFeature
-
const AuthmeFeature('passport') - NFCPassport → const AuthmeFeature
-
const AuthmeFeature('NFCPassport') - JPNID → const AuthmeFeature
-
const AuthmeFeature('JPNID') - JPNIDNFC → const AuthmeFeature
-
const AuthmeFeature('JPNNFCID') - JPNDriverLicense → const AuthmeFeature
-
const AuthmeFeature('JPNDriverLicense') - JPNDriverLicenseNFC → const AuthmeFeature
-
const AuthmeFeature('JPNNFCDriverLicense') - JPNResidentCard → const AuthmeFeature
-
const AuthmeFeature('JPNResidentCard') - JPNResidentCardNFC → const AuthmeFeature
-
const AuthmeFeature('JPNNFCResidentCard') - USAID → const AuthmeFeature
-
const AuthmeFeature('USAID') - USADriverLicense → const AuthmeFeature
-
const AuthmeFeature('USADriverLicense') - USAVisitorVISA → const AuthmeFeature
-
const AuthmeFeature('USAVisitorVISA') - IDNID → const AuthmeFeature
-
const AuthmeFeature('IDNID') - IDNDriverLicense → const AuthmeFeature
-
const AuthmeFeature('IDNDriverLicense') - Liveness → const AuthmeFeature
-
const AuthmeFeature('Liveness') - PassportWithVIZ → const AuthmeFeature
-
const AuthmeFeature('PassportWithVIZ') - INDID → const AuthmeFeature
-
const AuthmeFeature('INDID') - INDDriverLicense → const AuthmeFeature
-
const AuthmeFeature('INDDriverLicense') - MYSID → const AuthmeFeature
-
const AuthmeFeature('MYSID') - MYSDriverLicense → const AuthmeFeature
-
const AuthmeFeature('MYSDriverLicense') - HKGID → const AuthmeFeature
-
const AuthmeFeature('HKGID') - HKGIDFront → const AuthmeFeature
-
const AuthmeFeature('HKGIDFront') - HKGDriverLicense → const AuthmeFeature
-
const AuthmeFeature('HKGDriverLicense') - GBRID → const AuthmeFeature
-
const AuthmeFeature('GBRID') - GBRDriverLicense → const AuthmeFeature
-
const AuthmeFeature('GBRDriverLicense') - EGYID → const AuthmeFeature
-
const AuthmeFeature('EGID') - EGYDriverLicense → const AuthmeFeature
-
const AuthmeFeature('EGDriverLicense') - SAUID → const AuthmeFeature
-
const AuthmeFeature('SAID') - SAUDriverLicense → const AuthmeFeature
-
const AuthmeFeature('SADriverLicense') - NLDID → const AuthmeFeature
-
const AuthmeFeature('NLID') - NLDDriverLicense → const AuthmeFeature
-
const AuthmeFeature('NLDriverLicense') - SGPID → const AuthmeFeature
-
const AuthmeFeature('SGPID') - SGPDriverLicense → const AuthmeFeature
-
const AuthmeFeature('SGPDriverLicense')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - rawValue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCardTypes(
) → List< CardType> -
Available on AuthmeFeature, provided by the ScanTypeExtensions extension
-
getOCRCardType(
) → OCRCardType -
Available on AuthmeFeature, provided by the ScanTypeExtensions extension
返回對應的 OCRCardType -
getScanDocCardType(
) → List< OCRType> -
Available on AuthmeFeature, provided by the ScanTypeExtensions extension
返回對應的 OCRType 列表 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthmeFeature> - A constant List of the values in this enum, in order of their declaration.